*run using STATA 14

clear
clear matrix
set more off

log using "\Analysis\piratesofmed_reducedform.txt", text replace
use "\Analysis\baselinedata"


*missing price or exit tax
gen missingprice=(lprice==.)
replace puertos=1 if missingprice==1 & puertos==0


*appendix table 1:
tab puertos if trip=="mss2963"
tab puertos if trip=="l118l120"
tab puertos if trip=="l119"
tab puertos if trip=="l122"
tab puertos if trip=="l121"
tab puertos if trip=="l125"
tab puertos if trip=="mss3872"
tab puertos if trip=="l133"
tab puertos if trip=="l132"
tab puertos if trip=="mss3597"
tab puertos if trip=="mss4359"
tab puertos if trip=="l139"
tab puertos if trip=="mss4394"
tab puertos if trip=="mss3586"
tab puertos if trip=="mss3593"
tab puertos if trip=="l135"
tab puertos if trip=="mss2974"
tab puertos if trip=="mss7752"
tab puertos if trip=="l146"
tab puertos if trip=="mss4363"
tab puertos if trip=="l145"
tab puertos if trip=="l147"

*dropping if price is missing or only exit tax or similar is paid
drop if puertos==1
drop puertos

**generating variables
*child under 12
gen child=(age<12)
replace child=. if age==.

*ageatcaptivity
gen ageatcap=age-timecaptive

*exactcapture
gen exactcapture=year-timecaptive

*clustering by year of capture
gen clusteryear=int(exactcapture)

*generating data for the structural section
preserve
gen earmarked=(ladj!=.)
keep earmarked bundled age	timecaptive originalmanuscript folio	year lprice	female	fisherman	carrera	cleric	serviceoftheking	noble	othercommon	notidentified	missedtrip	clusteryear	ageatcap	child
outsheet using "\Structural\structuraldata.csv" , comma nolabel replace
restore

*generating data for figure 2 of the main text
preserve
gen numbercap=1
collapse(sum) numbercap, by(latitudehome longitudehome)

*drop if home is not known
drop if latitudehome==.
outsheet latitudehome longitudehome numbercap using "\Map\captivehomesbaselinesample.csv" , comma nolabel replace
restore


*generating data for figure 1 of the appendix
preserve
gen numbercap=1
collapse(sum) numbercap, by(exactcapturelat exactcapturelong)

*drop if place of capture is unknown
drop if exactcapturelat==.
outsheet numbercap exactcapturelat exactcapturelong using "\Map\placeofcapturebaselinesample.csv" , comma nolabel replace
restore


*table 2 of appendix
sum year
sum lprice
sum ladj
sum age
sum timecaptive
sum ageatcap
sum female
sum child
sum mainland
sum missedtrip

sum fisherman 
sum carrera 
sum serviceoftheking 
sum cleric
sum noble 
sum othercommon 
sum notidentified

**distances
*seville
vincenty 37.389092 -5.984459 latitudehome longitudehome, hav(sevdis) inkm

*madrid
vincenty 40.416775 -3.70379 latitudehome longitudehome, hav(maddis) inkm

*valencia
vincenty 39.469908 -.376288 latitudehome longitudehome, hav(valdis) inkm

*alicante
vincenty 38.345996 -0.490686 latitudehome longitudehome, hav(alidis) inkm

*cartagena
vincenty 37.625683 -0.996584 latitudehome longitudehome, hav(cartdis) inkm

*algiers
vincenty 36.752887 3.042048 latitudehome longitudehome, hav(algdis) inkm

gen ldisalg=ln(1+algdis)
drop algdis

egen mindis=rowmin(sevdis maddis cartdis valdis alidis)

gen ldis=ln(1+mindis)

*table 2 of appendix rows distances to bargaining bases and algiers
sum ldis
sum ldisalg

*100 times the coefficients
replace lprice=100*lprice

*omitting notidentified category
global profession  fisherman carrera cleric serviceoftheking noble othercommon

*table 3 of appendix
*col 1
reg lprice $profession, r

*col 2
reg lprice $profession, cluster(clusteryear)

*col 3
areg lprice $profession, absorb(trip) cluster(clusteryear)

*col 4
areg lprice timecaptive ageatcap $profession child female, absorb(trip) cluster(clusteryear)

*col 5
areg lprice timecaptive ageatcap $profession child female if ldis!=., absorb(trip) cluster(clusteryear)

*generating trip dummies
tab trip, gen(t)

gen earmarked=(ladj!=.)
*footnote 31
reg earmarked ldis, cluster(clusteryear)
areg earmarked ldis, absorb(trip) cluster(clusteryear)


*calculation of distance from place of capture to home
preserve
drop if latitudehome==.
drop if exactcapturelat==.

*gen distance from capture to home
vincenty latitudehome longitudehome exactcapturelat exactcapturelong, hav(discapt) inkm
gen ldiscap=ln(1+discapt)

*table 2 of appendix row on distance to capture
sum ldiscap

gen interaction=ldiscap*ldis
*footnote 33
areg lprice ldis ldiscap interaction, cluster(clusteryear) absorb(trip)




*appendix table 4, column 1
areg lprice timecaptive ageatcap ldiscap if ldis!=., absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap ldiscap t1-t22, first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap

*appendix table 4, column 2
areg lprice timecaptive ageatcap $profession female child ldiscap if ldis!=., absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap $profession female child ldiscap t1-t22, partial(t1-t22) first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap

*appendix table 4, column 3
gen ladj2=ladj^2

areg lprice timecaptive ageatcap  ladj ladj2 $profession female child ldiscap if ldis!=., absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis) ageatcap  ladj ladj2 $profession female child ldiscap  t1-t22,  partial(t1-t22) first cluster(clusteryear)
rivtest, ci 
test timecaptive=ageatcap


*within 50 km of bases
gen capitalcity=(sevdis<50 | maddis<50 | cartdis<50 | valdis<50 | alidis<50)
replace capitalcity=. if longitudehome==.

*appendix table 4, column 4
areg lprice timecaptive ageatcap ldiscap if ldis!=.  & mainland==1, absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap ldiscap t1-t22 if mainland==1, first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap

*appendix table 4, column 5
areg lprice timecaptive ageatcap $profession female child ldiscap if ldis!=.  & mainland==1, absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap $profession female child ldiscap t1-t22 if mainland==1, partial(t1-t22) first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap

*appendix table 4, column 6
areg lprice timecaptive ageatcap  ladj ladj2 $profession female child ldiscap if ldis!=.  & mainland==1, absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis) ageatcap  ladj ladj2 $profession female child ldiscap  t1-t22 if mainland==1,  partial(t1-t22) first cluster(clusteryear)
rivtest, ci 
test timecaptive=ageatcap


*appendix table 4, column 7
areg lprice timecaptive ageatcap capitalcity $profession female child ldiscap if ldis!=. & mainland==1, absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap capitalcity  $profession female child ldiscap t1-t22 if mainland==1, partial(t1-t22) first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap


restore

*figure 1
preserve
replace lprice=lprice/100
reg lprice, absorb(trip)
predict lpricer, r
reg ladj, absorb(trip)
predict ladjr, r
reg lpricer ladjr
twoway (scatter lpricer ladjr, ytitle("ln(Ransom)") xtitle("ln(Earmarked)") mc(gs10) legend(off)) (lfit lpricer ladjr, lcolor(gs0) lpattern(dash) graphregion(color(white) fcolor(white)) plotregion(color(white)))
graph export "\priceandearmarked.eps", as(eps) preview(off) replace
restore




*table 1, column 1
areg lprice timecaptive ageatcap if ldis!=., absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap t1-t22, first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap

*table 1, column 2
areg lprice timecaptive ageatcap $profession female child if ldis!=., absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap $profession female child t1-t22, partial(t1-t22) first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap

*table 1, column 3
gen ladj2=ladj^2

areg lprice timecaptive ageatcap  ladj ladj2 $profession female child if ldis!=., absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis) ageatcap  ladj ladj2 $profession female child  t1-t22,  partial(t1-t22) first cluster(clusteryear)
rivtest, ci 
test timecaptive=ageatcap


*within 50 km of bases
gen capitalcity=(sevdis<50 | maddis<50 | cartdis<50 | valdis<50 | alidis<50)
replace capitalcity=. if longitudehome==.

*table 1, column 4
areg lprice timecaptive ageatcap if ldis!=.  & mainland==1, absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap t1-t22 if mainland==1, first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap

*table 1, column 5
areg lprice timecaptive ageatcap $profession female child if ldis!=.  & mainland==1, absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap $profession female child t1-t22 if mainland==1, partial(t1-t22) first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap

*table 1, column 6
areg lprice timecaptive ageatcap  ladj ladj2 $profession female child if ldis!=.  & mainland==1, absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis) ageatcap  ladj ladj2 $profession female child  t1-t22 if mainland==1,  partial(t1-t22) first cluster(clusteryear)
rivtest, ci 
test timecaptive=ageatcap


*table 1, column 7
areg lprice timecaptive ageatcap capitalcity $profession female child if ldis!=. & mainland==1, absorb(trip) cluster(clusteryear)
test timecaptive=ageatcap

ivreg2 lprice (timecaptive=ldis)  ageatcap capitalcity  $profession female child t1-t22 if mainland==1, partial(t1-t22) first cluster(clusteryear)
rivtest, ci
test timecaptive=ageatcap

*100 times the coefficients in the earmarked regressios
replace ladj=ladj*100

*table 2, column 1
areg ladj ldis ageatcap $profession female child, absorb(trip) cluster(clusteryear)

*table 2, column 2
areg ladj ldis ageatcap $profession female child if mainland==1, absorb(trip) cluster(clusteryear)

*table 2, column 3
areg timecaptive ldisalg ageatcap $profession female child, absorb(trip) cluster(clusteryear)

*table 2, column 4
areg timecaptive ldisalg ageatcap $profession female child if mainland==1, absorb(trip) cluster(clusteryear)

*table 2, column 5
areg lprice ldisalg ageatcap $profession female child, absorb(trip) cluster(clusteryear)

*table 2, column 6
areg lprice ldisalg ageatcap $profession female child if mainland==1, absorb(trip) cluster(clusteryear)





log close
