clear
cd('C:\Dropbox\Pirates (2)\Structural'); % Root folder
%data=load('structuraldata2.mat');
T=readtable('structuraldata2.csv','ReadVariableNames',0);
data = table2array(T);
%data=data.data;

N=6; %cutoff for the max number of offers

%if one uses parfor
%matlabpool open 8

Boot=50; %number of draws for bootstrap
sterrors=1; %compute standard errors if 1
figures=1; %create figures if 1
counterfact=1; %counterfactuals if 1
filename = 'results5.xlsx';
sheet ='N=6,all prices';

% Sample
%data=data(data(:,6)==1,:); %only Algiers
data(isnan(data(:,2)),:)=[]; % time in captivity
data(isnan(data(:,4)),:)=[]; %price in reales
data(isnan(data(:,14)),:)=[]; %number of missed trips
%data(data(:,6)==1,:)=[]; %no females 
data(data(:,4)==0,:)=[]; %drop if the price is 0
data(data(:,14)>N-1,:)=[]; %dropping negotiations with duration >N
%data(isnan(data(:,9)),:)=[]; %only earmarked (robustness)
%-----------------------------

controls=[data(:,2),data(:,16),data(:,6),data(:,15),data(:,7:12),data(:,18:end)];
% [time in captivity,age when captured,female, child, data(7)-data(12)
% are profession dummies, data(18)-data(40) are book dummies]

%controls=[controls earmarked]; %plus earmarked
contexist=sum(controls,2); %all data on controls exists
data(isnan(contexist),:)=[]; %---
controls(isnan(contexist),:)=[]; %---
y=data(:,4);
missedtrips=data(:,14);
%subtracting one random missed trip with probability 30%
%draw=(rand(length(missedtrips),1)>0.7);
%missedtrips=missedtrips-draw.*(missedtrips>0);
%------------------------------------------------

%starting parameters
sd=0.42; %variance
lambda=0.35; %arrival probability
r=0.05; %common interest rate
agingS=0.03; %depreciation rate x
prob=0.3; %probability of no funds in the first round
tailcoef=1.6; %v_min/v_res
resvalue=0.4; %v_res

%initial search
results=zeros(1,8); %vector of results
%[sd,prob,agingS,r,v_min/v_res,v_res]

% initial search takes M values along each dimention one variable at a time
M=100;
temp=zeros(M,1);
for j=1:M
    temp(j)=LogL(y,missedtrips,controls,lambda,N,0.1+(0.9-0.1)/(M-1)*(j-1),prob,agingS,r,tailcoef,resvalue);
end
[~, J]=min(temp);
results(1)=0.1+(0.9-0.1)*(J-1)/(M-1);

for j=1:M
    temp(j)=LogL(y,missedtrips,controls,lambda,N,results(1),prob,agingS,r,tailcoef,0+0.8/(M-1)*(j-1));
end
[~, J]=min(temp);
results(6)=0+0.8/(M-1)*(J-1);

for j=1:M
    temp(j)=LogL(y,missedtrips,controls,lambda,N,results(1),prob,0+0.1/(M-1)*(j-1),r,tailcoef,results(6));
end
[~, J]=min(temp);
results(3)=0+0.1/(M-1)*(J-1);

for j=1:M
    temp(j)=LogL(y,missedtrips,controls,lambda,N,results(1),prob,results(3),...
        0.03+(0.07-0.03)*(j-1)/(M-1),tailcoef,results(6));
end
[~, J]=min(temp);
results(4)=0.03+(0.07-0.03)*(J-1)/(M-1);

for j=1:M
    temp(j)=LogL(y,missedtrips,controls,lambda,N,results(1),0+0.6/(M-1)*(j-1),results(3),results(4),tailcoef,results(6));
end
[~, J]=min(temp);
results(2)=0+0.6/(M-1)*(J-1);

for j=1:M
    temp(j)=LogL(y,missedtrips,controls,lambda,N,results(1),results(2),results(3),...
        results(4),1.1+(2-1.1)/(M-1)*(j-1),results(6));
end
[~, J]=min(temp);
results(5)=1.1+(2-1.1)/(M-1)*(J-1);
% ----------------------------------------------------------------------------

%fminsearch optimization LogL is -LogL in the text (is minimized)
options = optimset('Display','iter');
optfunction=@(x)LogL(y,missedtrips,controls,lambda,N,x(1),x(2),x(3),x(4),x(5),x(6));
[results(1:6), results(7),results(8)]=fminsearch(optfunction,results(1:6),options);

[pricefunc,distrib,lost,Vseq]=equilibrium(exp(1),lambda,N,results(1),results(2)...
    ,results(3),results(4),results(5),results(6)); %computing equilibrium
pricepredic=log(pricefunc(missedtrips+1)); %log predicted prices
x = lscov(controls(:,2:end),y-pricepredic-results(3)*controls(:,1)); %linear coefficients

%outputting results

A = {'Parameter','Value'; 'sd',results(1); 'prob',results(2); 'x',results(3);...
    'r',results(4);'v_min/v_res',results(5);'v_res',results(6)/exp(1);...
    'age when captured',x(1);'Female',x(2);'Child',x(3);'profession dummies','yes';'trip dummies','yes';...
    'Nobs',length(data)};
xlswrite(filename,A,sheet);

%% bootstrapted standard errors
if sterrors==1
    
resboot=zeros(Boot,6);
Lmin=zeros(Boot,1);
Flag=zeros(Boot,1);
xboot=zeros(Boot,length(x));
options = optimset('Display','off');

for i=1:Boot
    draw=ceil(rand(length(y),1)*length(y));
    yboot=y(draw);
    missedtripsboot=missedtrips(draw);
    controlsboot=controls(draw,:);
    temp=zeros(M,1);
    restemp=zeros(1,8);
for j=1:M
    temp(j)=LogL(yboot,missedtripsboot,controlsboot,lambda,N,0.1+(0.9-0.1)/(M-1)*(j-1),prob,agingS,r,tailcoef,resvalue);
end
[~, J]=min(temp);
restemp(1)=0.1+(0.9-0.1)*(J-1)/(M-1);

for j=1:M
    temp(j)=LogL(yboot,missedtripsboot,controlsboot,lambda,N,restemp(1),prob,agingS,r,tailcoef,0+0.8/(M-1)*(j-1));
end
[~, J]=min(temp);
restemp(6)=0+0.8/(M-1)*(J-1);

for j=1:M
    temp(j)=LogL(yboot,missedtripsboot,controlsboot,lambda,N,restemp(1),prob,0+0.1/(M-1)*(j-1),r,tailcoef,restemp(6));
end
[~, J]=min(temp);
restemp(3)=0+0.1/(M-1)*(J-1);

for j=1:M
    temp(j)=LogL(yboot,missedtripsboot,controlsboot,lambda,N,restemp(1),prob,restemp(3),...
        0.03+(0.07-0.03)*(j-1)/(M-1),tailcoef,restemp(6));
end
[~, J]=min(temp);
restemp(4)=0.03+(0.07-0.03)*(J-1)/(M-1);

for j=1:M
    temp(j)=LogL(yboot,missedtripsboot,controlsboot,lambda,N,restemp(1),0+0.6/(M-1)*(j-1),restemp(3),restemp(4),tailcoef,restemp(6));
end
[~, J]=min(temp);
restemp(2)=0+0.6/(M-1)*(J-1);

for j=1:M
    temp(j)=LogL(yboot,missedtripsboot,controlsboot,lambda,N,restemp(1),restemp(2),restemp(3),...
        restemp(4),1.1+(2-1.1)/(M-1)*(j-1),restemp(6));
end
[~, J]=min(temp);
restemp(5)=1.1+(2-1.1)/(M-1)*(J-1);

%fminsearch optimization LogL is -LogL in the text (is minimized)
optfunction=@(x)LogL(yboot,missedtripsboot,controlsboot,lambda,N,x(1),x(2),x(3),x(4),x(5),x(6));
[resboot(i,:),Lmin(i),Flag(i)]=fminsearch(optfunction,restemp(1:6),options);

[pricefunc,distrib,lost,Vseq]=equilibrium(exp(1),lambda,N,restemp(1),restemp(2)...
    ,restemp(3),restemp(4),restemp(5),restemp(6)); %computing equilibrium
pricepredicboot=log(pricefunc(missedtripsboot+1));
xboot(i,:) = lscov(controlsboot(:,2:end),yboot-pricepredicboot-restemp(3)*controlsboot(:,1));
    display(i);
end

%standard errors
resstand=std(resboot);
xstand=std(xboot);
B={'standard errors';resstand(1);resstand(2);resstand(3);resstand(4);resstand(5);resstand(6);xstand(1);xstand(2);xstand(3)};
xlswrite(filename,B,sheet,'C1');

end
%% figures
if figures==1
[pricefunc,distrib,lost,Vseq]=equilibrium(exp(1),lambda,N,results(1),results(2)...
    ,results(3),results(4),results(5),results(6)); %computing equilibrium
pricepredic=log(pricefunc(missedtrips+1));
x = lscov(controls(:,2:end),y-pricepredic-results(3)*controls(:,1));
FS=24;
MS=16;
LS=3;

n=hist(missedtrips+1,6)/sum(hist(missedtrips+1,6));
set(gca,'FontSize',FS);
bar([n',distrib]);
xlim([0,6.5]);
ylim([0,0.45]);
colormap gray;
hleg=legend('observed frequences','predicted frequences');
set(hleg,'FontSize',FS);
xlabel('Offer number','FontSize',FS);ylabel('Frequency','FontSize',FS);
print('-depsc','picture1');

figure
set(0,'DefaultAxesColorOrder',[0 0 0],'DefaultAxesLineStyleOrder','-|-.|--|:');
means = exp(grpstats(y-results(3)*controls(:,1)-controls(:,2:end)*x-1,missedtrips));
p1=plot(1:1:6,means,':','Marker','o','LineWidth',LS,'MarkerSize',MS);
set(gca,'FontSize',FS);
hold all
p2=plot(1:1:6,pricefunc/exp(1),':','Marker','*','LineWidth',LS,'MarkerSize',MS);
set(gca,'XTick',1:1:6)
xlim([0.5,6.5]);
ylim([0.4,0.75]);
hleg=legend('observed average price','predicted price');
set(hleg,'FontSize',FS);
xlabel('Offer number','FontSize',FS);ylabel('Transaction price','FontSize',FS);
print('-depsc','picture2');
end

%% counterfactuals
if counterfact==1;
T=1000;
% surplus distribution
[pricefunc,distrib,lost,Vseq]=equilibrium(exp(1),lambda,N,results(1),results(2)...
    ,results(3),results(4),results(5),results(6)); %computing equilibrium
beta=lambda/(lambda+results(3)+results(4));
powers=0:1:N-1;
tail=logncdf(results(6)*results(5),1,results(1));
sellervalue=sum((beta.^powers'.*pricefunc+results(6)*(1-beta.^powers')).*distrib)+...
    lost*beta^N*results(6)-results(6);
pv=linspace(tail+0.0001,0.9999,T);
vbuyer=logninv(pv,1,results(1));
buyervalue=(vbuyer-pricefunc(1)).*(vbuyer>Vseq(1))*(1-results(2));
buyervalue=buyervalue+(1-results(2))*beta*(vbuyer-pricefunc(2)).*(vbuyer>Vseq(2)).*(vbuyer<Vseq(1))+...
    results(2)*beta*(vbuyer-pricefunc(2)).*(vbuyer>Vseq(2));
for i=3:N
    buyervalue=buyervalue+beta^(i-1)*(vbuyer-pricefunc(i)).*(vbuyer>Vseq(i)).*(vbuyer<Vseq(i-1));
end
buyervalue=sum(buyervalue)/T;
totvalue=sum(vbuyer)/T-results(6);
delaycosts=totvalue-sellervalue-buyervalue;
row1=[sellervalue,buyervalue,delaycosts,totvalue];

% 10 random captives bunddled together
[mean,sd]=lognstat(1,results(1));
[pricefunc,distrib,lost,Vseq]=equilibrium_normal(mean,lambda,N,sd/sqrt(10),results(2),results(3)...
    ,results(4),results(5),results(6));
beta=lambda/(lambda+results(3)+results(4));
powers=0:1:N-1;
sellervalue=sum((beta.^powers'.*pricefunc+results(6)*(1-beta.^powers')).*distrib)+...
    lost*beta^N*results(6)-results(6);
vbuyer=norminv(pv,mean,sd/sqrt(10));
buyervalue=(vbuyer-pricefunc(1)).*(vbuyer>Vseq(1))*(1-results(2));
buyervalue=buyervalue+(1-results(2))*beta*(vbuyer-pricefunc(6)).*(vbuyer>Vseq(2)).*(vbuyer<Vseq(1))+...
    results(2)*beta*(vbuyer-pricefunc(2)).*(vbuyer>Vseq(2));
for i=3:N
    buyervalue=buyervalue+beta^(i-1)*(vbuyer-pricefunc(i)).*(vbuyer>Vseq(i)).*(vbuyer<Vseq(i-1));
end
buyervalue=sum(buyervalue)/T;
totvalue=mean-results(6);
delaycosts=totvalue-sellervalue-buyervalue;
row2=[sellervalue,buyervalue,delaycosts,totvalue];

% take-it-or-leave-it offer
tail=logncdf(results(5)*results(6),1,results(1));
pv=linspace(tail+0.0001,0.9999,T);
values=logninv(pv,1,results(1));
[~,priceind]=max(values.*(1-pv)+pv*results(6));
price=values(priceind);
sellervalue=price*(1-pv(priceind))+pv(priceind)*results(6)-results(6);
buyervalue=sum((values-price).*(values>price))/T;
totvalue=sum(values)/T-results(6);
delaycosts=totvalue-sellervalue-buyervalue;
row3=[sellervalue,buyervalue,delaycosts,totvalue];

values=[row1',row2',row3']/exp(1);
distribution=zeros(4,3);
distribution(1,:)=values(1,:)./values(4,:);
distribution(2,:)=values(2,:)./values(4,:);
distribution(3,:)=values(3,:)./values(4,:);
distribution(4,:)=1;
distribution=distribution*100; % in percents

C={'','screening','bundles of 10','take-it-or-leave-it';...
    '','percent of total','percent of total','percent of total';...
    'seller surplus',distribution(1,1),distribution(1,2),distribution(1,3);...
    'buyer surplus',distribution(2,1),distribution(2,2),distribution(2,3);...
    'delay/termination',distribution(3,1),distribution(3,2),distribution(3,3);...
    'total surplus',100,100,100};
xlswrite(filename,C,sheet,'F1');
end